birdlife_threats: Get bird threat information from BirdLife/IUCN

View source: R/birdlife.R

birdlife_threatsR Documentation

Get bird threat information from BirdLife/IUCN

Description

Get bird threat information from BirdLife/IUCN

Usage

birdlife_threats(id)

Arguments

id

A single IUCN species ID

Value

a data.frame with the species ID and two levels of threat descriptions, plus stresses, timing, scope, severity, and impact associated with each stressor.

Author(s)

David J. Harris harry491@gmail.com

See Also

Other birdlife: birdlife_habitat()

Examples

# Input validation runs before any HTTP request
try(birdlife_threats(c(22721692, 22678440)))


if (interactive()) {
  # Setophaga chrysoparia
  birdlife_threats(22721692)
  # Aburria aburri
  birdlife_threats(22678440)
}


traits documentation built on April 10, 2026, 5:06 p.m.