Skip to contents

Get bird threat information from BirdLife/IUCN

Usage

birdlife_threats(id)

Arguments

id

A single IUCN species ID

Value

a data.frame with the species ID and two levels of threat descriptions, plus stresses, timing, scope, severity, and impact associated with each stressor.

See also

Other birdlife: birdlife_habitat()

Author

David J. Harris harry491@gmail.com

Examples

# \donttest{
if (interactive()) {
  # Setophaga chrysoparia
  birdlife_threats(22721692)
  # Aburria aburri
  birdlife_threats(22678440)
}
# }